@@ -15,7 +15,7 @@
 # You should have received a copy of the GNU General Public License along
 # with PFT.  If not, see <http://www.gnu.org/licenses/>.
 #
-package PFT::Content v1.0.4;
+package PFT::Content v1.1.0;
 
 =encoding utf8
 
@@ -420,12 +420,12 @@ sub blog_back {
     my $path = (sort { $b cmp $a } @globs)[$back];
 
     my $h = eval { PFT::Header->load($path) };
-    $h or croak "Loading $path: " . $@ =~ s/ at .*$//rs;
+    $h or carp("Loading $path: " . $@ =~ s/ at .*$//rs);
 
     PFT::Content::Blog->new({
         tree => $self,
         path => $path,
-        name => $h->title,
+        name => $h ? $h->title : '?',
     })
 }
 
