@@ -15,7 +15,7 @@
 # You should have received a copy of the GNU General Public License along
 # with PFT.  If not, see <http://www.gnu.org/licenses/>.
 #
-package PFT::Content::Base v1.0.4;
+package PFT::Content::Base v1.1.0;
 
 =encoding utf8
 
@@ -86,6 +86,11 @@ use overload
         my $self = shift;
         ref($self) . '({name => "' . $self->{name} . '"})'
     },
+    'cmp' => sub {
+        my($self, $oth, $swap) = @_;
+        my $out = $self->name cmp $oth->name;
+        $swap ? -$out : $out;
+    }
 ;
 
 =back
