@@ -15,7 +15,7 @@
 # You should have received a copy of the GNU General Public License along
 # with PFT.  If not, see <http://www.gnu.org/licenses/>.
 #
-package PFT::Header v1.0.4;
+package PFT::Header v1.1.0;
 
 =encoding utf8
 
@@ -174,7 +174,7 @@ sub load {
     }
 
     my $hdr = eval { YAML::Tiny::Load($text) };
-    $hdr or confess 'Loading header: ' . $@ =~ s/ at .*$//rs;
+    $hdr or confess "File has corrupt header";
 
     my $date;
     $hdr->{Date} and $date = eval {
